%chisquared
% Function which demonstrates the generation of random numbers from an
% Chi-Qquared distribution. Samples are taken from this distribution, and the
% distribution of sample means is determined via a normalized histogram.
% From this the Central Limit Theorem is illustrated. i.e. the distribution
% of sample means tends to a normal distribution if the number of elements
% per sample is large enough.
%
% LAST UPDATED by Dr Andrew French September 2017

function chisquared

%% INPUTS %%

%Define mean value
mu = 10;

%Define number of samples
N = 1e4;

%Define number of elements per sample
n = 42;

%Define number of elements in probability density
npx = 1000;

%Number of histogram bin edges over range [xmin,xmax]
num_edges = 150;

%Calculate stadard deviation sigma
sigma = sqrt(2*mu);

%Range of x values for probability density function
xmin = 0;
xmax = mu+4*sigma;

%Define title string for this distribution
title_str = {['Normalized histogram of N=',...
    num2str(N),' samples of n=',num2str(n)],...
    ['\chi^2 distribution \mu=',num2str(mu),', \sigma=',num2str(sigma)]};

%Define filename for PNG output
name = 'chisquared';

%Fontsize for graphs
fsize = 18;

%

%Define probability density function
xx = linspace(xmin,xmax,1000);
a = (2^(mu/2))*gamma(mu/2);
a = 1/a;
px = a*(xx.^( mu/2 -1)).*exp( -xx/2);

%Generate an n by N array of uniformly distributed random numbers in the
%range [0,1]
z = rand(n,N);

%Use the inverse function of the probability P(x) to compute x values
x = 2*gammaincinv( z, mu/2 ) ;

%Plot normalized histogram of x data, and sample means
plot_normalized_histograms(x,xx,px,mu,sigma,num_edges,name,title_str,fsize)

%End of code




