%exponential
% Function which demonstrates the generation of random numbers from an
% exponential distribution with mean and variance 1/lambda. Samples are
% taken from this distribution, and the distribution of sample means is
% determined via a normalized histogram. From this the Central Limit
% Theorem is illustrated. i.e. the distribution of sample means tends to a
% normal distribution if the number of elements per sample is large enough.
%
% LAST UPDATED by Dr Andrew French September 2017

function exponential

%% INPUTS %%

%Define mean value (same as standard deviation)
mu = 3;

%Define number of samples
N = 1e4;

%Define number of elements per sample
n = 42;

%Define number of elements in probability density
npx = 1000;

%Range of x values for probability density function
xmin = 0;
xmax = 12;

%Number of histogram bin edges over range [xmin,xmax]
num_edges = 150;

%Define title string for this distribution
title_str = {['Normalized histogram of N=',...
    num2str(N),' samples of n=',num2str(n)],...
    ['Exponential distribution \mu=',num2str(mu),', \sigma=',num2str(mu)]};

%Define filename for PNG output
name = 'exponential';

%Fontsize for graphs
fsize = 18;

%

%Define probability density function
xx = linspace(xmin,xmax,1000);
lambda = 1/mu;
px = lambda*exp(-lambda*xx);

%Generate an n by N array of uniformly distributed random numbers in the
%range [0,1]
z = rand(n,N);

%Use the inverse function of the probability P(x) to compute x values
x = -log( 1-z)/lambda;

%Plot normalized histogram of x data, and sample means
sigma = mu;
plot_normalized_histograms(x,xx,px,mu,sigma,num_edges,name,title_str,fsize)

%End of code




