%gamma_distribution
% Function which demonstrates the generation of random numbers from an
% Gamma distribution. Samples are taken from this distribution, and the
% distribution of sample means is determined via a normalized histogram.
% From this the Central Limit Theorem is illustrated. i.e. the distribution
% of sample means tends to a normal distribution if the number of elements
% per sample is large enough.
%
% LAST UPDATED by Dr Andrew French October 2017

function gamma_distribution

%% INPUTS %%

%Define weibull parameters (these need to both be positive)
k = 5;
theta = 3;

%Define number of samples
N = 1e4;

%Define number of elements per sample
n = 42;

%Define number of elements in probability density
npx = 1000;

%Number of histogram bin edges over range [xmin,xmax]
num_edges = 150;

%Calculate Weibull distribution mean and standard deviation
mu = k*theta;
sigma = sqrt( k*theta^2 );

%Range of x values for probability density function
xmin = 0;
xmax = mu + 4*sigma;

%Define title string for this distribution
title_str = {['Normalized histogram of N=',...
    num2str(N),' samples of n=',num2str(n)],...
    ['Gamma distribution \mu=',num2str(mu),', \sigma=',num2str(sigma),', k=',num2str(k),', \theta=',num2str(theta)]};

%Define filename for PNG output
name = 'gamma';

%Fontsize for graphs
fsize = 18;

%

%Define probability density function
xx = linspace(xmin,xmax,1000);
px = ( xx.^(k-1) ).*exp(-xx/theta)/( gamma(k) * theta^k );

%Generate an n by N array of uniformly distributed random numbers in the
%range [0,1]
z = rand(n,N);

%Use the inverse function of the probability P(x) to compute x values
x = theta*gammaincinv( z,k );

%Plot normalized histogram of x data, and sample means
plot_normalized_histograms(x,xx,px,mu,sigma,num_edges,name,title_str,fsize)

%End of code




