%normal
% Function which demonstrates the generation of random numbers from a
% Normal distribution. Samples are taken from this
% distribution, and the distribution of sample means is determined via a
% normalized histogram. From this the Central Limit Theorem is
% illustrated. i.e. the distribution of sample means tends to a normal
% distribution if the number of elements per sample is large enough.
%
% LAST UPDATED by Dr Andrew French September 2017

function normal

%% INPUTS %%

%Define mean and standard deviation of Normal distribution
mu = 3;
sigma = 1;

%Define number of samples
N = 1e4;

%Define number of elements per sample
n = 42;

%Define number of elements in probability density
npx = 1000;

%Range of x values for probability density function
xmin = mu - 3*sigma;
xmax = mu + 3*sigma;

%Number of histogram bin edges over range [xmin,xmax]
num_edges = 150;

%Define title string for this distribution
title_str = {['Normalized histogram of N=',...
    num2str(N),' samples of n=',num2str(n)],...
    ['Normal distribution \mu=',num2str(mu),', \sigma=',num2str(sigma)]};

%Define filename for PNG output
name = 'normal';

%Fontsize for graphs
fsize = 18;

%

%Define probability density function
xx = linspace(xmin,xmax,1000);
px = (1/sqrt(2*pi*sigma^2))*exp( -(1/(2*sigma^2))*(xx - mu).^2 );

%Generate an n by N array of uniformly distributed random numbers in the
%range [0,1]
z = rand(n,N);

%Use the inverse function of the probability P(x) to compute x values
x = mu + sigma*sqrt(2)*erfinv(2*z-1);

%Plot normalized histogram of x data, and sample means
plot_normalized_histograms(x,xx,px,mu,sigma,num_edges,name,title_str,fsize)

%End of code




