%parabolic
% Function which demonstrates the generation of random numbers from a
% continuous (ish!) probability distribution defined by a parabola in the
% range [0,2], with minima at (1,0). Samples are taken from this
% distribution, and the distribution of sample means is determined via a
% normalized histogram. From this the Central Limit Theorem is
% illustrated. i.e. the distribution of sample means tends to a normal
% distribution if the number of elements per sample is large enough.
%
% LAST UPDATED by Dr Andrew French September 2017

function parabolic

%% INPUTS %%

%Define number of samples
N = 1e4;

%Define number of elements per sample
n = 42;

%Define number of elements in probability density
npx = 1000;

%Range of x values for probability density function
xmin = 0;
xmax = 2;

%Number of histogram bin edges over range [xmin,xmax]
num_edges = 150;

%Define title string for this distribution
title_str = {['Normalized histogram of N=',...
    num2str(N),' samples of n=',num2str(n)],...
    ['Parabolic distribution \mu=1, \sigma=',num2str(sqrt(3/5))]};

%Define filename for PNG output
name = 'parabolic';

%Fontsize for graphs
fsize = 18;

%

%Define probability density function
xx = linspace(xmin,xmax,1000);
px = (3/2)*(xx-1).^2;

%Generate an n by N array of uniformly distributed random numbers in the
%range [0,1]
z = rand(n,N);

%Use the inverse function of the probability P(x) to compute x values
%from the distribution p(x) = (3/2)*(x-1)^2 in range 0<=x<=2, 0 otherwise.
%P(x) = 0 in range x<=0,  0.5*( (x-1)^3) + 1 ) in range 0<=x<=2 and 1 for x>=2
x = nthroot( 2*z-1, 3 ) + 1;

%Plot normalized histogram of x data, and sample means
mu = 1;
sigma = sqrt(3/5);
plot_normalized_histograms(x,xx,px,mu,sigma,num_edges,name,title_str,fsize)

%End of code




