%uniform
% Function which demonstrates the generation of random numbers from an
% Uniform distribution. Samples are taken from this distribution, and the
% distribution of sample means is determined via a normalized histogram.
% From this the Central Limit Theorem is illustrated. i.e. the distribution
% of sample means tends to a normal distribution if the number of elements
% per sample is large enough.
%
% LAST UPDATED by Dr Andrew French September 2017

function uniform

%% INPUTS %%

%Define range of uniform distribution
a = 1;
b = 3;

%Define number of samples
N = 1e4;

%Define number of elements per sample
n = 42;

%Define number of elements in probability density
npx = 1000;

%Range of x values for probability density function
xmin = 0;
xmax = 5;

%Number of histogram bin edges over range [xmin,xmax]
num_edges = 150;

%Calculate mean mu and standard deviation sigma
mu = 0.5*(a+b);
sigma = sqrt( (1/12)*(b-a)^2 );

%Define title string for this distribution
title_str = {['Normalized histogram of N=',...
    num2str(N),' samples of n=',num2str(n)],...
    ['Uniform distribution \mu=',num2str(mu),', \sigma=',num2str(sigma)]};

%Define filename for PNG output
name = 'uniform';

%Fontsize for graphs
fsize = 18;

%

%Define probability density function
xx = linspace(xmin,xmax,1000);
px = ones(size(xx))/(b-a);
px( xx < a ) = 0;
px( xx > b ) = 0;

%Generate an n by N array of uniformly distributed random numbers in the
%range [0,1]
z = rand(n,N);

%Use the inverse function of the probability P(x) to compute x values
x = a + (b-a)*z;

%Plot normalized histogram of x data, and sample means
plot_normalized_histograms(x,xx,px,mu,sigma,num_edges,name,title_str,fsize)

%End of code




