%geometric
% Simulation of the generation of random numbers x ~ Geo(p) i.e. a
% Geometric distribution with probablity of success in independent binary
% trials p. x is the number of trials up to and including success.
%
% LAST UPDATED by Andy French September 2017

function geometric

%% INPUTS %%

%Number of Geometric distributed numbers
N = 1e6;

%Probability of success
p=0.3;

%Maximum number of trials up to and including success
xmax = ceil(7/p);

%Fontsize for graphs
fsize = 18;

%Distribution name
name = 'geometric';

%Graph title string
title_str = ['Normalized histogram of ',num2str(N),...
    ' samples of x ~ Geo(',num2str(p),')'];

%

%Determine Geometric probabilities
P = zeros(1,xmax);
for k=1:xmax
    P(k) = p*((1-p)^(k-1));
end

%Discrete distributions (in this program!) must have an x=0 term
P = [0,P];

%Generate random numbers and plot graph
generate_numbers_and_histogram(N,P,title_str,name,fsize);

%End of code