%poisson
% Simulation of the generation of random numbers x ~ Po(lambda) i.e. a
% Poisson distribution with mean rate lambda of (discrete) occurances in a fixed time
% frame. The occurances x can be 0,1,2.....
%
% LAST UPDATED by Andy French September 2017

function poisson

%% INPUTS %%

%Number of Poisson distributed numbers
N = 1e5;

%Mean rate of occurances
lambda = 7.4;

%Maximum number of occurances
xmax = ceil(3*lambda);

%Fontsize for graphs
fsize = 18;

%Distribution name
name = 'poisson';

%Graph title string
title_str = ['Normalized histogram of ',num2str(N),...
    ' samples of x ~ Po(',num2str(lambda),')'];

%

%Determine Poisson probabilities
P = zeros(1,xmax+1);
for k=0:xmax
    P(k+1) = (lambda^k)*exp(-lambda)/factorial(k);
end

%Generate random numbers and plot graph
generate_numbers_and_histogram(N,P,title_str,name,fsize);

%End of code